# AI Handler

This is a simple library which can be used to run AI models. It is a light wrapper around the huggingface API
which gives you a queue, threading, a simple API, and the ability to run Stable Diffusion and LLMs seamlessly
from your local hardware.

It can easily be extended and used to power interfaces or it can be run from the command line.

AI Handler is a work in progress. It powers two projects at the moment, but may not be ready for general use.

## Installation

```
pip install aihandler
```

## Usage

Examples coming soon, for now take a look at the following projects:

- [AI Runner](https://github.com/Capsize-Games/airunner)
- [Chat AI](https://github.com/Capsize-Games/airunner)